==> philib-0.10.0-sources.jar: ch/bind/philib/pool/object/MultiPoolStats.java <==
/*
 * Copyright (c) 2012 Philipp Meinen <philipp@bind.ch>
 * 
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"),
 * to deal in the Software without restriction, including without limitation
 * the rights to use, copy, modify, merge, publish, distribute, sublicense,
 * and/or sell copies of the Software, and to permit persons to whom the Software
 * is furnished to do so, subject to the following conditions:
 * 
 * The above copyright notice and this permission notice shall be included
 * in all copies or substantial portions of the Software.
 * 
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
 * EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
 * MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.
 * IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM,
 * DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT,
 * TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH
 * THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 */
package ch.bind.philib.pool.object;

import ch.bind.philib.pool.PoolStats;

/**
 * Collects buffer statistics from multiple pools in a concurrent environment.
 * 
 * @author Philipp Meinen
 */
final class MultiPoolStats implements PoolStats {

	private PoolStats[] stats;

	MultiPoolStats(PoolStats[] stats) {
		this.stats = stats;
	}

	@Override
	public long getCreates() {
		long c = 0;
		for (PoolStats s : stats) {
			c += s.getCreates();
		}
		return c;
	}

	@Override
	public long getTakes() {
		long t = 0;
		for (PoolStats s : stats) {
			t += s.getTakes();
		}
		return t;
	}

	@Override
	public long getRecycled() {
		long r = 0;
		for (PoolStats s : stats) {
			r += s.getRecycled();
		}
		return r;
	}

	@Override
	public long getReleased() {
		long r = 0;
		for (PoolStats s : stats) {
			r += s.getReleased();
		}
		return r;
	}

	@Override
	public String toString() {
		StringBuilder sb = new StringBuilder(256);
		sb.append("pool-total: creates=").append(getCreates());
		sb.append(", takes=").append(getTakes());
		sb.append(", recycled=").append(getRecycled());
		sb.append(", released=").append(getReleased());
		for (int i = 0; i < stats.length; i++) {
			sb.append("\n");
			sb.append("  pool-");
			sb.append(i);
			sb.append(": ");
			sb.append(stats[i]);
		}
		return sb.toString();
	}
}

==> philib-0.12.0-sources.jar: ch/bind/philib/pool/object/MultiPoolStats.java <==
/*
 * Copyright (c) 2012 Philipp Meinen <philipp@bind.ch>
 * 
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"),
 * to deal in the Software without restriction, including without limitation
 * the rights to use, copy, modify, merge, publish, distribute, sublicense,
 * and/or sell copies of the Software, and to permit persons to whom the Software
 * is furnished to do so, subject to the following conditions:
 * 
 * The above copyright notice and this permission notice shall be included
 * in all copies or substantial portions of the Software.
 * 
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
 * EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
 * MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.
 * IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM,
 * DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT,
 * TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH
 * THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 */
package ch.bind.philib.pool.object;

import ch.bind.philib.pool.PoolStats;

/**
 * Collects buffer statistics from multiple pools in a concurrent environment.
 *
 * @author Philipp Meinen
 */
final class MultiPoolStats implements PoolStats {

	private final PoolStats[] stats;

	MultiPoolStats(PoolStats[] stats) {
		this.stats = stats;
	}

	@Override
	public long getCreates() {
		long c = 0;
		for (PoolStats s : stats) {
			c += s.getCreates();
		}
		return c;
	}

	@Override
	public long getTakes() {
		long t = 0;
		for (PoolStats s : stats) {
			t += s.getTakes();
		}
		return t;
	}

	@Override
	public long getRecycled() {
		long r = 0;
		for (PoolStats s : stats) {
			r += s.getRecycled();
		}
		return r;
	}

	@Override
	public long getReleased() {
		long r = 0;
		for (PoolStats s : stats) {
			r += s.getReleased();
		}
		return r;
	}

	@Override
	public String toString() {
		StringBuilder sb = new StringBuilder(256);
		sb.append("pool-total: creates=").append(getCreates());
		sb.append(", takes=").append(getTakes());
		sb.append(", recycled=").append(getRecycled());
		sb.append(", released=").append(getReleased());
		for (int i = 0; i < stats.length; i++) {
			sb.append("\n");
			sb.append("  pool-");
			sb.append(i);
			sb.append(": ");
			sb.append(stats[i]);
		}
		return sb.toString();
	}
}
